@@ -19,7 +19,7 @@ config.logDebugToFile = False
 config.searchShowingOnly = True
 
 from dogtail import tree
-from dogtail.predicate import GenericPredicate
+from dogtail.predicate import GenericPredicate, IsAnApplicationNamed
 from dogtail.utils import run
 from gi.repository import Gio, GLib
 
@@ -31,9 +31,12 @@ class BaseTest(unittest.TestCase):
         super().setUp()
         self.restic = False
         self.dbus = None
-        self.reset_gsettings(self.get_settings())
+        self.reset_gsettings()
         self.set_string("tool-when-new", "duplicity")
 
+        # Kill nautilus, because some of our tests open windows
+        subprocess.run(["killall", "-q", "nautilus"])
+
         # Clean any previous cache files
         self.clean_cache()
 
@@ -74,6 +77,7 @@ class BaseTest(unittest.TestCase):
                 return
             timeout -= 1
             sleep(1)
+        self.get_app().dump()
         assert func()
 
     def get_bus_pid(self, name):
@@ -129,12 +133,14 @@ class BaseTest(unittest.TestCase):
     def get_app(self):
         return Gtk4Node(tree.root.application(os.environ["DD_APPID"]))
 
-    def reset_gsettings(self, settings):
+    def reset_gsettings(self, child=None):
+        settings = self.get_settings(child)
         schema = settings.get_property("settings-schema")
         for key in schema.list_keys():
-            settings.reset(key)
+            default = settings.get_default_value(key)
+            self.set_value(None, key, default, child=child)
         for child in schema.list_children():
-            self.reset_gsettings(settings.get_child(child))
+            self.reset_gsettings(child)
 
     def child(self, **kwargs):
         # If label= is provided, dogtail doesn't check any other traits
@@ -152,13 +158,20 @@ class BaseTest(unittest.TestCase):
                 pass
         return obj.parent.child(**kwargs)
 
-    def walk_initial_backup(self, app, password=None, wait=True, remember=False):
-        window = self.get_dialog(app)
-        window.button("Forward").click()  # folders
-        window.button("Forward").click()  # storage location
+    def wait_for_banner(self, parent, label, check_first=True):
+        if check_first:
+            parent.button(label)
+        self.wait_for(
+            lambda: not parent.findChild(
+                GenericPredicate(roleName="button", label=label),
+                retry=False,
+                requireResult=False,
+            ),
+            timeout=1200,
+        )
 
-        # window might have closed if auto-launched, so regrab it
-        window = self.get_dialog(app)
+    def walk_initial_backup(self, app, password=None, wait=True, remember=False):
+        window = self.get_alert(app)
         if password:
             window.child(roleName="text", label="Encryption password").text = password
             window.child(roleName="text", label="Confirm password").text = password
@@ -169,43 +182,38 @@ class BaseTest(unittest.TestCase):
                 roleName="check box", name="Password-protect your backup"
             ).click()
 
-        window.button("Forward").click()
+        window.button("Continue").click()
 
         if wait:
-            self.wait_for(lambda: window.dead, timeout=60)
-            return None
-        else:
-            return window
+            self.wait_for_banner(app, "Pause")
 
-    def walk_incremental_backup(self, app, password="", wait=True, title=None):
+    def walk_incremental_backup(self, app, password="", wait=True):
         if password:
-            window = self.get_dialog(app)
-            window.child(roleName="text", label="Encryption password").typeText(
-                password
-            )
-            window.button("Forward").click()
-        else:
-            window = self.get_dialog(app)
+            self.enter_browser_password(app, password)
 
         if wait:
-            self.wait_for(lambda: window.dead)
-            return None
-        else:
-            return window
+            self.wait_for_banner(app, "Pause")
 
     def enter_browser_password(self, app, password):
-        # I'm having trouble with Enter Password appearing visible to dogtail,
-        # but not really being rendered. So let's click it and see if a dialog appears.
-        def click_and_see():
-            app.button("Enter Password").click()
-            return app.findChild(
-                GenericPredicate(roleName="text entry", label="Encryption password"),
+        self.wait_for(
+            lambda: app.findChild(
+                GenericPredicate(roleName="text", label="Encryption password"),
                 retry=False,
                 requireResult=False,
-            )
+            ),
+            timeout=300,
+        )
+        app.child(roleName="text", label="Encryption password").text = password
+
+        # Confirm password if we are doing an initial backup
+        confirm = app.findChild(
+            GenericPredicate(roleName="text", label="Confirm password"),
+            retry=False,
+            requireResult=False,
+        )
+        if confirm:
+            confirm.text = password
 
-        self.wait_for(click_and_see)
-        app.child(roleName="text entry", label="Encryption password").typeText(password)
         app.button("Continue").click()
 
     def get_file_chooser(self, name):
@@ -216,11 +224,20 @@ class BaseTest(unittest.TestCase):
 
         return dlg
 
+    def wait_for_file_manager(self):
+        self.wait_for(
+            lambda: "org.gnome.Nautilus" in {x.name for x in tree.root.children},
+            timeout=300,
+        )
+
+    def get_alert(self, app):
+        return app.child(roleName="alert")
+
     def get_dialog(self, app):
         return app.child(roleName="dialog")
 
     def click_restore_button(self, parent):
-        parent.child(roleName="button", name="Restore").click()
+        parent.child(roleName="button", name="Restore…").click()
 
     def get_config(self, section, option, fallback=None, required=True):
         if not self.config:
@@ -280,10 +297,12 @@ class BaseTest(unittest.TestCase):
             if child:
                 group += "/" + child
             if func == "set_int":
-                func = "new_int32"
-            else:
+                func = "set_int32"
+            if func:
                 func = func.replace("set_", "new_")
-            varvalue = getattr(GLib.Variant, func)(value)
+                varvalue = getattr(GLib.Variant, func)(value)
+            else:
+                varvalue = value
             keyfile.set_value(group, key, varvalue.print_(False))
             keyfile.save_to_file(os.environ["DD_KEYFILE"])
         else:
