@@ -7,7 +7,7 @@
 from subprocess import check_output
 
 import pyatspi
-from dogtail import rawinput
+from dogtail import rawinput, tree
 from dogtail.config import config
 from dogtail.predicate import GenericPredicate
 from dogtail.tree import Node, SearchError
@@ -29,6 +29,7 @@ class Gtk4Node:
         try:
             c = func(*args, **kwargs, showingOnly=False)
         except SearchError:
+            tree.root.dump()
             self.node.dump()  # a little debugging help
             raise
         if c is None:
@@ -91,7 +92,7 @@ class Gtk4Node:
 
         # Fix coords to take into account client side decorations.
         # Hardcoding this is super gross, I'd love a better way.
-        self.coords = (top.node.position[0] + 50, top.node.position[1] + 50)
+        self.coords = (top.node.position[0] + 30, top.node.position[1] + 30)
 
     def _get_position(self) -> tuple[int, int]:
         # Dogtail's default position uses DESKTOP_COORDS, which modern GTK
