@@ -60,8 +60,10 @@ class BackupTest(BaseTest):
 
     def test_from_main_window(self):
         app = self.cmd()
-        app.childNamed("Create Your First Backup").click()
+        app.childNamed("Create Your First Backup…").click()
         with self.new_files():
+            window = self.get_dialog(app)
+            window.button("Back Up").click()
             self.walk_initial_backup(app)
 
         with self.new_files():
@@ -88,11 +90,12 @@ class BackupTest(BaseTest):
         keyCombo("<Super>v")
         sleep(1)
         keyCombo("Enter")
+        keyCombo("Enter")
         app = self.get_app()
 
         # ensure window has focus (different modes either get rid of
         # notification drawer or not...)
-        app.child(name="Folders to Back Up").click()
+        self.get_alert(app).click()
 
         with self.new_files():
             self.walk_initial_backup(app)
@@ -104,10 +107,7 @@ class BackupTest(BaseTest):
         os.chmod(self.rootdir, stat.S_IRUSR | stat.S_IXUSR)
         app = self.cmd("--backup")
         with self.new_files(False):
-            window = self.get_dialog(app)
-            window.button("Forward").click()  # folders
-            window.button("Forward").click()  # storage location
-            window.childNamed("Backup Failed")
+            window = self.get_alert(app)
             window.button("Close").click()
 
     def test_encrypted(self):
@@ -140,8 +140,9 @@ class BackupTest(BaseTest):
 
         app = self.cmd("--backup")
         with self.new_files():
-            window = self.get_dialog(app)
-            window.button("Forward").click()
+            window = self.get_alert(app)
+            window.child(roleName="label", name="Computer Name Changed")
+            window.button("Continue").click()
             self.walk_incremental_backup(app)
 
     @ddt.data(True, False)
@@ -156,12 +157,12 @@ class BackupTest(BaseTest):
         self.randomize_srcdir()
         app = self.cmd("--backup")
         if initial:
-            window = self.walk_initial_backup(app, password="t", wait=False)
+            self.walk_initial_backup(app, password="t", wait=False)
         else:
-            window = self.walk_incremental_backup(app, password="t", wait=False)
+            self.walk_incremental_backup(app, password="t", wait=False)
 
         def mid_progress():
-            bar = window.findChild(
+            bar = app.findChild(
                 GenericPredicate(roleName="progress bar"),
                 retry=False,
                 requireResult=False,
@@ -172,28 +173,28 @@ class BackupTest(BaseTest):
             self.wait_for(mid_progress)
             sleep(0.2)  # give time for duplicity to write a .part file
             app.button("Pause").click()
-            self.wait_for(lambda: window.dead)
+            self.wait_for_banner(app, "Pause", check_first=False)
 
         assert last_backup == self.get_string("last-backup")
         assert last_run != self.get_string("last-run")
 
         app = self.cmd("--backup")
         self.walk_incremental_backup(app, password="nope", wait=False)
-        window = self.walk_incremental_backup(app, password="t", wait=False)
+        self.walk_incremental_backup(app, password="t", wait=False)
         self.did_resume = False
 
         def finish_progress():
             try:
-                if window.dead:
-                    return True
-                bar = window.findChild(
+                bar = app.findChild(
                     GenericPredicate(roleName="progress bar"),
                     retry=False,
                     requireResult=False,
                 )
-                if bar and bar.value >= 0.3:
+                if not bar:
+                    return True
+                elif bar.value >= 0.3:
                     self.did_resume = True
-                elif bar and not self.did_resume:
+                elif not self.did_resume:
                     assert bar.value == 0
                 return False
             except GLib.GError:
@@ -201,7 +202,7 @@ class BackupTest(BaseTest):
 
         with self.new_files():
             self.wait_for(finish_progress, timeout=120)
-            assert window.dead
+            self.wait_for_banner(app, "Pause", check_first=False)
 
     def test_no_passphrase_change_on_full(self):
         """
@@ -232,18 +233,13 @@ class BackupTest(BaseTest):
         # Wait for prompt (a little longer to appear than normal dogtail timeouts)
         self.wait_for(
             lambda: app.findChild(
-                lambda x: x.roleName == "text" and x.name == "Encryption password",
+                lambda x: x.roleName == "password text" and x.name == "Encryption password",
                 requireResult=False,
                 retry=False,
             )
         )
-        self.walk_incremental_backup(
-            app, password="nope", title="Restore Test", wait=False
-        )
-        self.walk_incremental_backup(
-            app, password="t", title="Restore Test", wait=False
-        )
-        app.button("Close").click()  # we have a confirmation screen after nag
+        self.walk_incremental_backup(app, password="nope", wait=False)
+        self.walk_incremental_backup(app, password="t")
 
         assert self.get_string("nag-check") != months_ago
 
@@ -258,3 +254,24 @@ class ResticBackupTest(ResticMixin, BackupTest):
     @skip("hostname question doesn't exist in restic")
     def test_hostname_question(self):
         super().test_hostname_question()
+
+
+class MainUITest(BaseTest):
+    def setUp(self):
+        super().setUp()
+
+        # Set up destination
+        self.destdir = self.rootdir + "/dest"
+        self.set_string("backend", "local")
+        self.set_string("folder", self.destdir, child="local")
+
+    def test_dialog_does_not_block_new_backups(self):
+        app = self.cmd("--backup")
+        self.walk_initial_backup(app, password="t")
+        app = self.cmd("--backup")
+        # confirm there is now be a password dialog showing
+        entry = app.child(roleName="text entry", label="Encryption password")
+        app = self.cmd("--backup", "--auto")
+        self.wait_for(lambda: entry.dead)
+        # new password dialog is waiting
+        self.walk_incremental_backup(app, password="t")
