@@ -14,7 +14,7 @@ from dogtail.predicate import GenericPredicate
 from dogtail.rawinput import holdKey, keyCombo, pressKey, releaseKey, typeText
 from gi.repository import GLib
 
-from . import BaseTest, ResticMixin
+from . import BaseTest
 
 
 class BrowserTest(BaseTest):
@@ -35,32 +35,21 @@ class BrowserTest(BaseTest):
     def use_backup_dir(self, path):
         basedir = os.path.realpath(os.path.join(os.path.dirname(__file__)))
         srcfiles = basedir + "/" + path
-
-        backupdir = GLib.get_home_dir() + "/.deja-dup-test/dest"
-        os.makedirs(backupdir, exist_ok=True)
-        shutil.rmtree(backupdir, ignore_errors=True)
-        shutil.copytree(srcfiles, backupdir, ignore=shutil.ignore_patterns("*.license"))
-        self.set_string("folder", backupdir, child="local")
-
-    def switch_to_restore(self):
-        widget = self.app.child(roleName="label", name="Restore", showingOnly=False)
-        while widget.parent:
-            widget = widget.parent
-            if widget.roleName == "page tab":
-                widget.click()
-                return
-        assert False
+        self.set_string("folder", srcfiles, child="local")
 
     def scan(self, error=None):
-        self.switch_to_restore()
-
-        if self.password:
-            self.enter_browser_password(self.app, self.password)
+        self.app.button("Browse Backups").click()
 
         if error:
             self.app.child(roleName="label", name=error)
             return
 
+        # Select most recent snapshot
+        self.app.child(roleName="list item").click()
+
+        if self.password:
+            self.enter_browser_password(self.app, self.password)
+
         search = self.app.child(roleName="toggle button", name="Search")
         self.wait_for(lambda: search.sensitive)
 
@@ -97,7 +86,11 @@ class BrowserTest(BaseTest):
         self.password = "test"
         self.use_backup_dir("duplicity2")
         self.scan()
-        self.snapshots = ["06/07/20 09:33:07", "06/07/20 09:29:40", "06/04/20"]
+        self.snapshots = [
+            "Sun Jun \u20077 09:33:07 2020",
+            "Sun Jun \u20077 09:29:40 2020",
+            "Thu Jun \u20074 14:52:24 2020",
+        ]
 
     def scan_dir3(self):
         """
@@ -151,7 +144,7 @@ class BrowserTest(BaseTest):
     def select_location(self, where):
         self.addCleanup(shutil.rmtree, where, ignore_errors=True)
         self.window.child(
-            roleName="list item", name="Restore to specific folder"
+            roleName="list item", name="Restore files to a specific folder"
         ).click()
         self.window.child(roleName="button", name="Choose Folder").click()
         os.makedirs(where, exist_ok=True)
@@ -159,7 +152,7 @@ class BrowserTest(BaseTest):
         typeText(where + "\n")
         self.wait_for(lambda: dlg.dead)
 
-    def walk_restore(self, error=False, where=None):
+    def walk_restore(self, where=None):
         self.start_restore()
         shutil.rmtree(self.srcdir, ignore_errors=True)
 
@@ -168,20 +161,14 @@ class BrowserTest(BaseTest):
 
         self.window.button("Restore").click()  # to where
 
-        if self.password:
-            self.window.child(roleName="text", label="Encryption password").text = (
-                self.password
-            )
-            self.window.button("Forward").click()
-
-        title = "Restore Failed" if error else "Restore Finished"
         self.wait_for(
-            lambda: self.window.findChild(
-                GenericPredicate(name=title), retry=False, requireResult=False
+            lambda: not self.app.findChild(
+                GenericPredicate(roleName="button", label="Stop"),
+                retry=False,
+                requireResult=False,
             ),
-            timeout=60,
+            timeout=600,
         )
-        self.window.button("Close").click()
 
     def check_files(self, *file_args, where=None):
         if not where:
@@ -234,8 +221,7 @@ class BrowserTest(BaseTest):
     def test_select_all(self):
         self.scan_dir1()
 
-        restore_panel = self.app.child(roleName="panel", name="Restore")
-        icons = restore_panel.findChildren(lambda x: x.roleName == "table cell")
+        icons = self.app.findChildren(lambda x: x.roleName == "table cell")
         assert len(icons) == 4 and len([i for i in icons if i.selected]) == 0
 
         keyCombo("<Control>a")
@@ -268,40 +254,36 @@ class BrowserTest(BaseTest):
 
         # test dir navigation (could go in any test, but thrown in here)
         view = self.app.child(roleName="table")
-        back = self.app.child(roleName="button", name="Back")
-        assert not back.sensitive
+        up = self.app.child(roleName="button", name="Up")
+        assert not up.sensitive
         assert len(view.children) == 3
         dir1 = view.child(roleName="label", name="dir1")
         dir1.doubleClick()
-        assert back.sensitive
+        assert up.sensitive
         assert len(view.children) == 1
-        back.click()
-        assert not back.sensitive
+        up.click()
+        assert not up.sensitive
         assert len(view.children) == 3
 
-        # test time combo
-        dates_combo = self.app.child(roleName="combo box", label="Date")
-        dates_combo.click()
-        popover = dates_combo.child(roleName="scroll pane")
-        dates = [
-            x.name
-            for x in popover.findChildren(
-                lambda x: x.roleName == "label", showingOnly=False
-            )
-        ]
+        # Go back to date selection screen
+        back = self.app.child(roleName="button", name="Back")
+        back.click()
+
+        rows = self.app.findChildren(lambda x: x.roleName == "list item")
+        dates = [x.name for x in rows]
         assert self.snapshots == dates, dates
 
         # choose oldest date, it should have an extra item in it
-        pressKey("Down")
-        pressKey("Down")
-        pressKey("Return")
+        rows[-1].click()
         search = self.app.child(roleName="toggle button", name="Search")
         self.wait_for(lambda: search.sensitive)
         assert len(view.children) == 4
 
     def test_scan_error(self):
-        self.set_string("folder", GLib.get_home_dir() + "/.deja-dup-test/missing", child="local")
-        self.scan(error="No backup files found")
+        self.set_string(
+            "folder", GLib.get_home_dir() + "/.deja-dup-test/missing", child="local"
+        )
+        self.scan(error="No Backups Found")
 
     def test_bad_restore_permissions(self):
         os.makedirs(self.srcdir, exist_ok=True)
@@ -310,31 +292,37 @@ class BrowserTest(BaseTest):
         open(self.srcdir + "/one.txt", "w+").close()
         os.chmod(self.srcdir + "/one.txt", stat.S_IRUSR)
 
-        def findPermissionLabel(x):
-            return (
-                x.roleName == "label"
-                and x.name
-                == "Backups does not have permission to restore the following files:"
-            )
-
         self.scan_dir1()
         self.select("four.txt", "dir1")
         self.start_restore()
         button = self.window.button("Restore")
 
-        # Test can't backup
-        self.app.findChild(findPermissionLabel)
-        self.app.findChild(
+        # Confirm that we can't backup
+        help_button = self.window.findChild(
+            lambda x: x.roleName == "toggle button" and x.name == "Help"
+        )
+        help_button.click()
+        self.window.findChild(
+            lambda x: (
+                x.roleName == "label"
+                and x.name
+                == "Backups does not have permission to restore the following files:"
+            )
+        )
+        self.window.findChild(
             lambda x: x.roleName == "label" and x.name == self.srcdir + "/four.txt"
         )
         assert not button.sensitive
+        keyCombo("Escape")  # close popup
 
         # Test that we can if you switch locations
         self.select_location(self.restoredir)
-        label = self.app.findChild(
-            findPermissionLabel, retry=False, requireResult=False
+        help_button = self.window.findChild(
+            lambda x: x.roleName == "toggle button" and x.name == "Help",
+            retry=False,
+            requireResult=False,
         )
-        assert label is None
+        assert help_button is None
         assert button.sensitive
 
         self.window.button("Cancel").click()
@@ -349,29 +337,3 @@ class BrowserTest(BaseTest):
         self.select("1.txt", "subdir")
         self.walk_restore()
         self.check_files(("1.txt", "1"), ("subdir/2.txt", "2"))
-
-
-class ResticBrowserTest(ResticMixin, BrowserTest):
-    def scan_dir1(self):
-        self.password = "test1"
-        self.use_backup_dir("restic1")
-        self.scan()
-
-    def scan_dir2(self):
-        self.password = "test2"
-        self.use_backup_dir("restic2")
-        self.scan()
-        hostname = socket.gethostname()
-        if hostname != "tama":
-            self.snapshots = [
-                "08/02/21 15:34:06 (tama)",
-                "08/02/21 15:33:43 (tama)",
-                "07/28/21 (tama)",
-            ]
-        else:
-            self.snapshots = ["08/02/21 15:34:06", "08/02/21 15:33:43", "07/28/21"]
-
-    def scan_dir3(self):
-        self.password = "t"
-        self.use_backup_dir("restic3")
-        self.scan()
