@@ -16,8 +16,12 @@ from . import BaseTest
 class PreferencesTest(BaseTest):
     def setUp(self):
         super().setUp()
+
+        # Remove welcome screen so that we can get to preferences
+        now = GLib.DateTime.new_now_utc().format_iso8601()
+        self.set_string("last-run", now)
+
         self.app = self.cmd()
-        keyCombo("<Control>comma")
 
     def get_auto_check(self, root):
         box = root.child(roleName="list item", name="Back Up Automatically")
@@ -26,47 +30,30 @@ class PreferencesTest(BaseTest):
     def get_preferences_window(self):
         return self.get_dialog(self.app)
 
-    def test_general(self):
-        # Test that there's a special first time welcome screen
-        self.app.childNamed("Create Your First Backup")
-
-        # Grab switch from main window, set last-run time so the switch shows up
-        now = GLib.DateTime.new_now_utc().format_iso8601()
-        self.set_string("last-run", now)
-        main = self.app.window("Backups")
-        periodic_main = self.get_auto_check(main)
-
-        prefs = self.get_preferences_window()
+    def test_schedule(self):
+        self.app.child(roleName="list item", name="Schedule").click()
 
         # Periodic to settings
-        periodic = self.get_auto_check(prefs)
+        periodic = self.app.child(roleName="check box", name="Back Up Automatically")
         self.assertFalse(periodic.checked)
-        self.assertFalse(periodic_main.checked)
         periodic.click()
         self.assertTrue(self.get_boolean("periodic"))
 
         # Periodic from settings
         self.assertTrue(periodic.checked)
-        self.assertTrue(periodic_main.checked)
         self.set_boolean("periodic", False)
         self.wait_for(lambda: not self.refresh(periodic).checked)
-        self.wait_for(lambda: not self.refresh(periodic_main).checked)
         self.set_boolean("periodic", True)
         self.wait_for(lambda: self.refresh(periodic).checked)
-        self.wait_for(lambda: self.refresh(periodic_main).checked)
-
-        # Scroll to bottom
-        scrollbar = prefs.child(roleName="scroll bar")
-        scrollbar.node.value = 100
 
         # Period to settings
-        period = prefs.child(roleName="combo box", name="Automatic Backup Frequency")
+        period = self.app.child(roleName="combo box", name="Automatic Backup Frequency")
         period.click()
-        prefs.child(name="Daily").click()
+        self.app.child(name="Daily").click()
         self.assertEqual(self.get_int("periodic-period"), 1)
 
         period.click()
-        prefs.child(name="Weekly").click()
+        self.app.child(name="Weekly").click()
         self.assertEqual(self.get_int("periodic-period"), 7)
 
         # Period from settings
@@ -74,13 +61,13 @@ class PreferencesTest(BaseTest):
         self.refresh(period).child(name="Every 10 days")  # just test existence
 
         # Delete After to settings
-        delete = prefs.child(roleName="combo box", name="Keep Backups")
+        delete = self.app.child(roleName="combo box", name="Keep Backups")
         delete.click()
-        prefs.child(name="At least a year").click()
+        self.app.child(name="At least a year").click()
         self.assertEqual(self.get_int("delete-after"), 365)
 
         delete.click()
-        prefs.child(name="Forever").click()
+        self.app.child(name="Forever").click()
         self.assertEqual(self.get_int("delete-after"), 0)
 
         # Delete After from settings
@@ -100,10 +87,9 @@ class PreferencesTest(BaseTest):
         self.wait_for(lambda: self.table_names(table) == names)
 
     def assert_inclusion_table(self, widget, add_label, key):
-        prefs = self.get_preferences_window()
-        prefs.child(roleName="page tab", name="Folders").click()
+        self.app.child(roleName="list item", name="Folders").click()
 
-        table = prefs.child(roleName="list", name=widget)
+        table = self.app.child(roleName="list", name=widget)
 
         user = GLib.get_user_name()
         home = GLib.get_home_dir()
